@@ -8,7 +8,6 @@
 #define __LIBXMLPP_NODES_CDATANODE_H
 
 #include <libxml++/nodes/contentnode.h>
-#include <libxml++/api_export.h>
 
 namespace xmlpp
 {
@@ -16,7 +15,7 @@ namespace xmlpp
 /** CData node. This will be instantiated by the parser.
  *
  */
-class LIBXMLPP_API CdataNode : public ContentNode
+class CdataNode : public ContentNode
 {
 public:
   explicit CdataNode(_xmlNode* node);
